pub enum DestructData {
Noop,
Implicit,
Glue {
ty: Ty,
},
}Variants
Noop
A drop that does nothing, e.g. for scalars and pointers.
Implicit
An implicit Destruct local clause, if the resolve_destruct_bounds option is false. If
that option is true, we’ll add Destruct bounds to every type param, and use that to
resolve Destruct impls of generics. If it’s false, we use this variant to indicate that
the clause comes from a generic or associated type.
Glue
The drop_in_place is known and non-trivial.