Enum AssocItemResolution
pub enum AssocItemResolution {
None,
TraitProof,
ImplItem,
}Variants
None
Leave trait associated items as plain item references.
TraitProof
Resolve the trait proof of a trait associated item, but keep the trait item id.
ImplItem
Resolve the trait proof and, when possible, point to the concrete impl item.